@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
 version: 1.3.3
-id: authenticate-1.3.3-53ea91e5c026eab440060c4bf4b2b35c
-key: authe_79qzWMDb1Zw1KNHdw2uGY1
+id: authenticate-1.3.3-93c9f5420bfbd80e8b14a192df0f3642
+key: authe_9oC8YLtAh0u9ABEDFgDHJf
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,10 +23,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
-hs-libraries: HSauthenticate-1.3.3-79qzWMDb1Zw1KNHdw2uGY1
+hs-libraries: HSauthenticate-1.3.3-9oC8YLtAh0u9ABEDFgDHJf
 depends:
-    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
-    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
+    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
+    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -38,11 +38,11 @@ depends:
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    tagstream-conduit-0.5.5.3-8fa377501d8cf106e7f32f768f3613df
+    tagstream-conduit-0.5.5.3-b744539fdc663e8763385d836cf273a8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
-    xml-conduit-1.3.4-929e1b83c5cd543381c444e44eb0de12
+    xml-conduit-1.3.4-978b9ab149c55d47c395c4e421ee22a7
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
